Attribute

Enum Attribute 

#[non_exhaustive]
pub enum Attribute {
Show 28 variants Reset, Bold, Dim, Italic, Underlined, DoubleUnderlined, Undercurled, Underdotted, Underdashed, SlowBlink, RapidBlink, Reverse, Hidden, CrossedOut, Fraktur, NoBold, NormalIntensity, NoItalic, NoUnderline, NoBlink, NoReverse, NoHidden, NotCrossedOut, Framed, Encircled, OverLined, NotFramedOrEncircled, NotOverLined,
}
Available on crate feature term only.
Represents an attribute.

Platform-specific Notes

  • Only UNIX and Windows 10 terminals do support text attributes.
  • Keep in mind that not all terminals support all attributes.
  • Crossterm implements almost all attributes listed in the SGR parameters.
AttributeWindowsUNIXNotes
Reset
Bold
Dim
Italic??Not widely supported, sometimes treated as inverse.
Underlined
SlowBlink??Not widely supported, sometimes treated as inverse.
RapidBlink??Not widely supported. MS-DOS ANSI.SYS; 150+ per minute.
Reverse
HiddenAlso known as Conceal.
FrakturLegible characters, but marked for deletion.
DefaultForegroundColor??Implementation specific (according to standard).
DefaultBackgroundColor??Implementation specific (according to standard).
Framed??Not widely supported.
Encircled??This should turn on the encircled attribute.
OverLined??This should draw a line at the top of the text.

Examples

Basic usage:

use crossterm::style::Attribute;

println!(
    "{} Underlined {} No Underline",
    Attribute::Underlined,
    Attribute::NoUnderline
);

Style existing text:

use crossterm::style::Stylize;

println!("{}", "Bold text".bold());
println!("{}", "Underlined text".underlined());
println!("{}", "Negative text".negative());

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Reset

Resets all the attributes.



Bold

Increases the text intensity.



Dim

Decreases the text intensity.



Italic

Emphasises the text.



Underlined

Underlines the text.



DoubleUnderlined

Double underlines the text.



Undercurled

Undercurls the text.



Underdotted

Underdots the text.



Underdashed

Underdashes the text.

Makes the text blinking (< 150 per minute).

Makes the text blinking (>= 150 per minute).



Reverse

Swaps foreground and background colors.



Hidden

Hides the text (also known as Conceal).



CrossedOut

Crosses the text.



Fraktur

Sets the Fraktur typeface.

Mostly used for mathematical alphanumeric symbols.



NoBold

Turns off the Bold attribute. - Inconsistent - Prefer to use NormalIntensity



NormalIntensity

Switches the text back to normal intensity (no bold, italic).



NoItalic

Turns off the Italic attribute.



NoUnderline

Turns off the Underlined attribute.

Turns off the text blinking (SlowBlink or RapidBlink).



NoReverse

Turns off the Reverse attribute.



NoHidden

Turns off the Hidden attribute.



NotCrossedOut

Turns off the CrossedOut attribute.



Framed

Makes the text framed.



Encircled

Makes the text encircled.



OverLined

Draws a line at the top of the text.



NotFramedOrEncircled

Turns off the Frame and Encircled attributes.



NotOverLined

Turns off the OverLined attribute.

Implementations



impl Attribute

pub fn iterator() -> impl Iterator<Item = Attribute>

Iterates over all the variants of the Attribute enum.



impl Attribute

pub const fn bytes(self) -> u32

Returns a u32 with one bit set, which is the signature of this attribute in the Attributes bitset.

The +1 enables storing Reset (whose index is 0) in the bitset Attributes.

pub fn sgr(self) -> String