Attributes

Struct Attributes 

pub struct Attributes(/* private fields */);
Available on crate feature term only.
a bitset for all possible attributes

Implementations



impl Attributes

pub const fn none() -> Attributes

Returns the empty bitset.

pub const fn with(self, attribute: Attribute) -> Attributes

Returns a copy of the bitset with the given attribute set. If it’s already set, this returns the bitset unmodified.

pub const fn without(self, attribute: Attribute) -> Attributes

Returns a copy of the bitset with the given attribute unset. If it’s not set, this returns the bitset unmodified.

pub fn set(&mut self, attribute: Attribute)

Sets the attribute. If it’s already set, this does nothing.

pub fn unset(&mut self, attribute: Attribute)

Unsets the attribute. If it’s not set, this changes nothing.

pub fn toggle(&mut self, attribute: Attribute)

Sets the attribute if it’s unset, unset it if it is set.

pub const fn has(self, attribute: Attribute) -> bool

Returns whether the attribute is set.

pub fn extend(&mut self, attributes: Attributes)

Sets all the passed attributes. Removes none.

pub const fn is_empty(self) -> bool

Returns whether there is no attribute set.